@@ -17,6 +17,7 @@ from .context import (
     _concatenate_sources,
 )
 from .specialize_source import specialize_source
+from .linkedarray import BaseLinkedArray
 
 log = logging.getLogger(__name__)
 
@@ -72,6 +73,15 @@ def cdef_from_kernel(kernel, pyname=None):
     signature += ");"
     return signature
 
+if _enabled:
+    # order of base classes matters as it defines which __setitem__ is used
+    class LinkedArrayCpu(BaseLinkedArray, np.ndarray):
+
+        @classmethod
+        def _build_view(cls, a):
+            assert len(a.shape) == 1
+            return cls(shape=a.shape, dtype=a.dtype, buffer=a.data, offset=0,
+                    strides=a.strides, order='C')
 
 class ContextCpu(XContext):
     """
@@ -88,6 +98,10 @@ class ContextCpu(XContext):
     def nplike_array_type(self):
         return np.ndarray
 
+    @property
+    def linked_array_type(self):
+        return LinkedArrayCpu
+
     def __init__(self, omp_num_threads=0):
         super().__init__()
         self.omp_num_threads = omp_num_threads
